resources (formerly outputs)
============================

Example files of resources (instances, networks, security groups, etc. from
a particular topology).

.. note:: Because there are multiple `outputs` from a provisioning run, the
   term is ambiguous. Changing the value to `resources` is indicative of the
   instances and other things that have been provisioned. Hopefully this
   provides clearer terminology and understanding.
